# Pixii

![PyPI - Status](https://img.shields.io/pypi/status/pixii) ![PyPI - Python Version](https://img.shields.io/pypi/pyversions/pixii) ![PyPI](https://img.shields.io/pypi/v/pixii) [![GitHub license](https://img.shields.io/github/license/k2bd/pixii)](https://github.com/k2bd/pixii/blob/main/LICENSE)

[![CI](https://github.com/k2bd/pixii/actions/workflows/ci.yml/badge.svg)](https://github.com/k2bd/pixii/actions/workflows/ci.yml) [![codecov](https://codecov.io/gh/k2bd/pixii/branch/main/graph/badge.svg?token=YEZCDAA1JZ)](https://codecov.io/gh/k2bd/pixii)
